/*************************************************************************
test.c

This program is used to test out some of my own Modbus read/write
functions, built on LibModbus function calls.

*************************************************************************/

#include <stdio.h>
#include <unistd.h>		// Necessary for the sleep() function
#include <modbus.h>		// Necessary for all modbus connection and data read/write functions
#include "cascada.h"		// Contains all the declarations specific to caSCADA

#define IP_ADDRESS "169.254.8.1"
#define TCP_PORT 502



int
main (void)
{

  char key;

  // Define Modbus/TCP device and port
  Device = modbus_new_tcp (IP_ADDRESS, TCP_PORT);


  // What to do if this function returns an error
  if (Device == NULL)
    {
      fprintf (stderr, "Unable to establish TCP port \n");
      return -1;
    }


  // This very important function call instructs the libmodbus
  // library functions to attempt recovery in the event of
  // network interruptions.  Without it, the default behavior
  // of libmodbus is to do nothing at all, leaving any network
  // error recovery to the user!
  modbus_set_error_recovery(Device, MODBUS_ERROR_RECOVERY_LINK);

  // Establish a Modbus connection and what to do if this fails
  if (modbus_connect (Device) == -1)
    {
      fprintf (stderr, "Unable to connect to Modbus device \n");
      modbus_free (Device);
      return -1;
    }




  // Main loop
  while (1)
    {
      
//      printf("Register 30001 = %i  \n", read_16int(30001));
//      printf("Register 30002 = %i  \n", read_16int(30002));
//      printf("Register 30015 = %i  \n", read_16int(30015));
//      printf("Register 30016 = %i  \n", read_16int(30016));
      printf("Register 40001 = %i  \n", read_16int(40001));
      printf("Register 42001 = %i  \n", read_16int(42001));
      printf("Register 42002 = %i  \n", read_16int(42002));
      printf("AIN0 = %f Volts \n", read_32float(40001,2));
      printf("AIN1 = %f Volts \n", read_32float(40003,2));
      printf("\n");
//      printf("TT-41 case temperature = %f deg F \n", read_32float(30005, 0));
//      printf("TT-41 battery voltage = %f Volts \n", read_32float(30007, 0));
//      printf("PT-44 pressure = %f Inches water column \n", read_32float(30011, 0));
//      printf("PT-44 case temperature = %f deg C \n", read_32float(30015, 0));
//      printf("PT-44 battery voltage = %f Volts \n", read_32float(30017, 0));
      
      sleep (1);
  
    }



  // Close Modbus connection
  modbus_close (Device);

  // Free Modbus device and TCP port
  modbus_free (Device);

  // Force of habit here -- I like all functions to return *something*
  return 1;

}


